@@ -4,12 +4,12 @@
 #' section. This function creates an object of class \code{mappoly.data}
 #' 
 #' The first line of the input file contains the string \code{ploidy} followed by the ploidy level of the parents.
-#' The second and third lines contain the strings \code{nind} and \code{nmrk} followed by the number of individuals in 
+#' The second and third lines contain the strings \code{n.ind} and \code{n.mrk} followed by the number of individuals in 
 #' the dataset and the total number of markers, respectively. Lines number 4 and 5 contain the strings
-#' \code{mrknames} and \code{indnames} followed by a sequence of the names of the markers and the name of the individuals, 
+#' \code{mrk.names} and \code{ind.names} followed by a sequence of the names of the markers and the name of the individuals, 
 #' respectively. Lines 6 and 7 contain the strings \code{dosageP} and \code{dosageQ} followed by a sequence of numbers 
 #' containing the dosage of all markers in parent \code{P} and \code{Q}. Line 8, contains the string seq followed by 
-#' a sequence of integer numbers indicating the sequence each marker belongs. It can be any 'a priori' 
+#' a sequence of integer numbers indicating the chromosome each marker belongs. It can be any 'a priori' 
 #' information regarding the physical distance between markers. For example, these numbers could refer 
 #' to chromosomes, scaffolds or even contigs, in which the markers are positioned. If this information 
 #' is not available for a particular marker, NA should be used. If this information is not available for 
@@ -46,19 +46,19 @@
 #'
 #' @return An object of class \code{mappoly.data} which contains a
 #'     list with the following components:
-#'     \item{m}{ploidy level}
+#'     \item{ploidy}{ploidy level}
 #'     \item{n.ind}{number individuals}
 #'     \item{n.mrk}{total number of markers}
 #'     \item{ind.names}{the names of the individuals}
 #'     \item{mrk.names}{the names of the markers}
-#'     \item{dosage.p}{a vector containing the dosage in
+#'     \item{dosage.p1}{a vector containing the dosage in
 #'       parent P for all \code{n.mrk} markers}
-#'     \item{dosage.q}{a vector containing the dosage in
+#'     \item{dosage.p2}{a vector containing the dosage in
 #'       parent Q for all \code{n.mrk} markers}
-#'     \item{sequence}{a vector indicating which sequence each marker
+#'     \item{chrom}{a vector indicating which sequence each marker
 #'       belongs. Zero indicates that the marker was not assigned to any
 #'       sequence}
-#'     \item{sequence.pos}{Physical position of the markers into the
+#'     \item{genome.pos}{Physical position of the markers into the
 #'       sequence}
 #'     \item{seq.ref}{NULL (unused in this type of data)}
 #'     \item{seq.alt}{NULL (unused in this type of data)}
@@ -70,8 +70,8 @@
 #'     \item{phen}{a matrix containing the phenotypic data. The rows
 #'                 correspond to the traits and the columns correspond
 #'                 to the individuals}
-#'     \item{kept}{if elim.redundant=TRUE, holds all non-redundant markers}
-#'     \item{elim.correspondence}{if elim.redundant=TRUE, holds all non-redundant markers and
+#'     \item{kept}{if elim.redundant = TRUE, holds all non-redundant markers}
+#'     \item{elim.correspondence}{if elim.redundant = TRUE, holds all non-redundant markers and
 #' its equivalence to the redundant ones}
 #' @examples
 #' \donttest{
@@ -105,7 +105,7 @@
 read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TRUE, verbose = TRUE) {
   ## get ploidy level ----------------------
   temp <- scan(file.in , what = character(), sep = " ", nlines = 1, quiet = TRUE)
-  m <- na.omit(as.numeric(temp[2]))
+  ploidy <- na.omit(as.numeric(temp[2]))
   ## get number of individuals -------------
   temp <- scan(file.in , what = character(), sep = " ", skip = 1, nlines = 1, quiet = TRUE)
   n.ind <- na.omit(as.numeric(temp[2]))
@@ -114,7 +114,7 @@ read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TR
   n.mrk <- na.omit(as.numeric(temp[2]))
   ## get marker names ----------------------
   temp <- scan(file.in , what = character(), sep = " ", skip = 3, nlines = 1, quiet = TRUE)
-  temp <- temp[!temp == ""]
+  temp <- temp[!temp  ==  ""]
   if (length(temp) - 1 != n.mrk)
     stop("\n\t\t----------------------------------
          Number of markers and length of marker
@@ -124,7 +124,7 @@ read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TR
   mrk.names <- na.omit(temp[-1])
   ## get individual names ------------------
   temp <- scan(file.in , what = character(), sep = " ", skip = 4, nlines = 1, quiet = TRUE)
-  temp <- temp[!temp == ""]
+  temp <- temp[!temp  ==  ""]
   if (length(temp) - 1 != n.ind)
     stop("\n\t\t----------------------------------
          Number of individuals and length of
@@ -134,9 +134,9 @@ read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TR
   ind.names <- na.omit(temp[-1])
   ## get dosage in parent P ----------------
   temp <- scan(file.in, what = character(), sep = " ", skip = 5, nlines = 1, quiet = TRUE)
-  temp <- temp[!temp == ""]
-  dosage.p <- na.omit(as.integer(temp[-1]))
-  if (length(dosage.p) != n.mrk)
+  temp <- temp[!temp  ==  ""]
+  dosage.p1 <- na.omit(as.integer(temp[-1]))
+  if (length(dosage.p1) != n.mrk)
     stop("\n\t\t--------------------------------------------------
          The number of markers and the length of the dosage
          vector for parent P do not match.\n
@@ -144,31 +144,31 @@ read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TR
          --------------------------------------------------\n")
   ## get dosage in parent Q ----------------
   temp <- scan(file.in, what = character(), sep = " ", skip = 6, nlines = 1, quiet = TRUE)
-  temp <- temp[!temp == ""]
-  dosage.q <- na.omit(as.integer(temp[-1]))
-  if (length(dosage.q) != n.mrk)
+  temp <- temp[!temp  ==  ""]
+  dosage.p2 <- na.omit(as.integer(temp[-1]))
+  if (length(dosage.p2) != n.mrk)
     stop("\n\t\t--------------------------------------------------
          The number of markers and the length of the dosage
          vector for parent Q do not match.\n
          Please, check data.
          --------------------------------------------------\n")
   ## monomorphic markers
-  dp<-abs(abs(dosage.p-(m/2))-(m/2))
-  dq<-abs(abs(dosage.q-(m/2))-(m/2))
-  id<-dp+dq!=0
-  ## get sequence info ---------------------
+  dp <- abs(abs(dosage.p1-(ploidy/2))-(ploidy/2))
+  dq <- abs(abs(dosage.p2-(ploidy/2))-(ploidy/2))
+  id <- dp+dq != 0
+  ## get chromosome info ---------------------
   temp <- scan(file.in , what = character(), sep = " ", skip = 7, nlines = 1, quiet = TRUE)
-  temp <- temp[!temp == ""]
+  temp <- temp[!temp  ==  ""]
   if (length(temp) - 1 != n.mrk && length(temp) - 1 > 1)
     stop("\n\t\t-------------------------------------
          Number of sequence indices and number of
          markers do not match.
          Please, check data.
          ------------------------------------------\n")
-  sequence <- as.integer(temp[-1])
+  chrom <- as.integer(temp[-1])
   ## get sequence position info ------------
   temp <- scan(file.in , what = character(), sep = " ", skip = 8, nlines = 1, quiet = TRUE)
-  temp <- temp[!temp == ""]
+  temp <- temp[!temp  ==  ""]
   if (length(temp) - 1 != n.mrk && length(temp) - 1 > 1)
     stop("\n\t\t--------------------------------------------------
          The number of sequence positions and the number of
@@ -176,7 +176,7 @@ read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TR
          Please, check data.
          --------------------------------------------------\n")
   sequencepos <- as.numeric(temp[-1])
-  names(sequencepos) <- names(sequence) <- names(dosage.q) <- names(dosage.p) <-  mrk.names
+  names(sequencepos) <- names(chrom) <- names(dosage.p2) <- names(dosage.p1) <-  mrk.names
   ## checking for phenotypic info ----------
   temp <- scan(file.in , what = character(), sep = " ", skip = 9, quiet = TRUE)
   nphen <- na.omit(as.numeric(temp[2]))
@@ -187,46 +187,46 @@ read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TR
   }
   if (verbose){
       cat("Reading the following data:")
-      cat("\n    Ploidy level:", m)
+      cat("\n    Ploidy level:", ploidy)
       cat("\n    No. individuals: ", n.ind)
       cat("\n    No. markers: ", n.mrk) 
       cat("\n    No. informative markers:  ", sum(id), " (", round(100*sum(id)/n.mrk,1), "%)", sep = "")
       if (all(unique(nphen) != 0))
           cat("\n    This dataset contains phenotypic information.")
       if (length(sequence) > 1)
-          cat("\n    This dataset contains sequence information.")
+          cat("\n    This dataset contains chromosome information.")
       cat("\n    ...\n")
   }
 
   ## get genotypic info --------------------
   geno.dose <- read.table(file.in , skip = 12 + nphen)
-  if(nrow(geno.dose)!=length(mrk.names))
+  if(nrow(geno.dose) != length(mrk.names))
     stop("\n\t\t-------------------------------------
          Number of marker names is different from
          the number of markers in the dataset.
          Please, check data.
          ------------------------------------------\n")
-  if(ncol(geno.dose)!=length(ind.names))
+  if(ncol(geno.dose) != length(ind.names))
     stop("\n\t\t-------------------------------------
          Number of individual names is different from
          the number of individuals in the dataset.
          Please, check data.
          ------------------------------------------\n")
-  dimnames(geno.dose)<-list(mrk.names, ind.names)
-  geno.dose[is.na(geno.dose)] <- m + 1
+  dimnames(geno.dose) <- list(mrk.names, ind.names)
+  geno.dose[is.na(geno.dose)] <- ploidy + 1
   ## returning the 'mappoly.data' object
   if (verbose) cat("\n    Done with reading.\n")
-  geno.dose<-geno.dose[id,]
+  geno.dose <- geno.dose[id,]
   
-  res <- structure(list(m = m,
+  res <- structure(list(ploidy = ploidy,
                         n.ind = n.ind,
                         n.mrk = sum(id),
                         ind.names = ind.names,
                         mrk.names = mrk.names[id],
-                        dosage.p = dosage.p[id],
-                        dosage.q = dosage.q[id],
-                        sequence = sequence[id],
-                        sequence.pos = sequencepos[id],
+                        dosage.p1 = dosage.p1[id],
+                        dosage.p2 = dosage.p2[id],
+                        chrom = chrom[id],
+                        genome.pos = sequencepos[id],
                         seq.ref = NULL,
                         seq.alt = NULL,
                         all.mrk.depth = NULL,
@@ -240,18 +240,18 @@ read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TR
   
   if(filter.non.conforming){
     if (verbose) cat("    Filtering non-conforming markers.\n    ...")
-    res<-filter_non_conforming_classes(res)
+    res <- filter_non_conforming_classes(res)
     if (verbose) cat("\n    Performing chi-square test.\n    ...")
     ##Computing chi-square p.values
-    Ds <- array(NA, dim = c(m+1, m+1, m+1))
-    for(i in 0:m)
-      for(j in 0:m)
-        Ds[i+1,j+1,] <- segreg_poly(m = m, dP = i, dQ = j)
-    Dpop<-cbind(res$dosage.p, res$dosage.q)
-    M<-t(apply(Dpop, 1, function(x) Ds[x[1]+1, x[2]+1,]))
-    dimnames(M)<-list(res$mrk.names, c(0:m))
-    M<-cbind(M, res$geno.dose)
-    res$chisq.pval<-apply(M, 1, mrk_chisq_test, m = m)
+    Ds <- array(NA, dim = c(ploidy+1, ploidy+1, ploidy+1))
+    for(i in 0:ploidy)
+      for(j in 0:ploidy)
+        Ds[i+1,j+1,] <- segreg_poly(ploidy = ploidy, dP = i, dQ = j)
+    Dpop <- cbind(res$dosage.p1, res$dosage.p2)
+    M <- t(apply(Dpop, 1, function(x) Ds[x[1]+1, x[2]+1,]))
+    dimnames(M) <- list(res$mrk.names, c(0:ploidy))
+    M <- cbind(M, res$geno.dose)
+    res$chisq.pval <- apply(M, 1, mrk_chisq_test, ploidy = ploidy)
     if (verbose) cat("\n    Done.\n")
   }
   if (elim.redundant){
@@ -261,18 +261,18 @@ read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TR
     res$kept = redun$kept
     res$elim.correspondence = redun$elim.correspondence
     mrks.rem = match(res$elim.correspondence$elim, res$mrk.names)
-    res$elim.correspondence$sequence = res$sequence[c(mrks.rem)]
-    res$elim.correspondence$sequence.pos = res$sequence.pos[c(mrks.rem)]
+    res$elim.correspondence$chrom = res$chrom[c(mrks.rem)]
+    res$elim.correspondence$genome.pos = res$genome.pos[c(mrks.rem)]
     res$elim.correspondence$seq.ref = NA
     res$elim.correspondence$seq.alt = NA
     res$elim.correspondence$all.mrk.depth = NA
     res$n.mrk = length(res$kept)
     res$mrk.names = res$mrk.names[-c(mrks.rem)]
     res$geno.dose = res$geno.dose[-c(mrks.rem),]
-    res$dosage.p = res$dosage.p[-c(mrks.rem)]
-    res$dosage.q = res$dosage.q[-c(mrks.rem)]
-    res$sequence = res$sequence[-c(mrks.rem)]
-    res$sequence.pos = res$sequence.pos[-c(mrks.rem)]
+    res$dosage.p1 = res$dosage.p1[-c(mrks.rem)]
+    res$dosage.p2 = res$dosage.p2[-c(mrks.rem)]
+    res$chrom = res$chrom[-c(mrks.rem)]
+    res$genome.pos = res$genome.pos[-c(mrks.rem)]
     res$chisq.pval = res$chisq.pval[-c(mrks.rem)]
   }
   return(res)
@@ -282,15 +282,15 @@ read_geno <- function(file.in, filter.non.conforming = TRUE, elim.redundant = TR
 #' @export
 print.mappoly.data <- function(x, detailed = FALSE, ...) {
   cat("This is an object of class 'mappoly.data'\n")
-  cat("    Ploidy level:                           ", x$m, "\n")
+  cat("    Ploidy level:                           ", x$ploidy, "\n")
   cat("    No. individuals:                        ", x$n.ind, "\n")
   cat("    No. markers:                            ", x$n.mrk, "\n")
-  miss<-round(100*sum(x$geno.dose==x$m+1)/length(as.matrix(x$geno.dose)),2)
+  miss <- round(100*sum(x$geno.dose == x$ploidy+1)/length(as.matrix(x$geno.dose)),2)
   if(!is.null(x$kept)){
     redundant = round(100*(nrow(x$elim.correspondence)/(length(x$kept)+nrow(x$elim.correspondence))),2)
   }
   ##if no prior probabilities
-  if(nrow(x$geno)==x$n.mrk){
+  if(is.prob.data(x)){
     cat("    Missing data:                            ", miss, "%\n", sep = "")  
   } else {
     cat("    Missing data under ", x$prob.thres, " prob. threshold: ", miss, "%\n", sep = "")    
@@ -298,16 +298,16 @@ print.mappoly.data <- function(x, detailed = FALSE, ...) {
   if(!is.null(x$kept)){
     cat("    Redundant markers:                       ", redundant, "%\n", sep = "")  
   }
-  w <- table(x$sequence)
+  w <- table(x$chrom)
   if (length(w) <= 1)
-    cat("\n    No. markers per sequence: not available") else if (detailed) {
-      cat("\n    ----------\n    No. markers per sequence:\n")
+    cat("\n    No. markers per chromosome: not available") else if (detailed) {
+      cat("\n    ----------\n    No. markers per chromosome:\n")
       print(data.frame(seq = paste0("       ", names(w)), No.mrk = as.numeric(w)), row.names = FALSE)
       cat("    ----------\n")
-      cat(paste0("    Markers with no sequence information: ", sum(is.na(x$sequence))))
-    } else cat("\n    This dataset contains sequence information.")
+      cat(paste0("    Markers with no chromosome information: ", sum(is.na(x$chrom))))
+    } else cat("\n    This dataset contains chromosome information.")
   cat("\n    ----------\n    No. of markers per dosage combination in both parents:\n")
-  freq <- table(paste(x$dosage.p, x$dosage.q, sep = "-"))
+  freq <- table(paste(x$dosage.p1, x$dosage.p2, sep = "-"))
   d.temp <- matrix(unlist(strsplit(names(freq), "-")), ncol = 2, byrow = TRUE)
   print(data.frame(P1 = paste0("    ", d.temp[, 1]), P2 = d.temp[, 2], freq = as.numeric(freq)), row.names = FALSE)
   if (x$nphen != 0)
@@ -319,17 +319,17 @@ print.mappoly.data <- function(x, detailed = FALSE, ...) {
 #' @importFrom graphics barplot layout mtext image legend 
 #' @importFrom grDevices colorRampPalette
 #' @importFrom grDevices blues9
-plot.mappoly.data <- function(x, thresh.line=10e-6, ...)
+plot.mappoly.data <- function(x, thresh.line = 10e-6, ...)
 {
-  freq <- table(paste(x$dosage.p, x$dosage.q, sep = "-"))
+  freq <- table(paste(x$dosage.p1, x$dosage.p2, sep = "-"))
   d.temp <- matrix(unlist(strsplit(names(freq), "-")), ncol = 2, byrow = TRUE)
-  type<-apply(d.temp, 1, function(x,m) paste0(sort(abs(abs(as.numeric(x)-(m/2))-(m/2))), collapse=""), m = x$m)
-  type.names<-names(table(type))
-  mrk.dist<-as.numeric(freq)
-  names(mrk.dist)<-apply(d.temp, 1 , paste, collapse = "-")
+  type <- apply(d.temp, 1, function(x,ploidy) paste0(sort(abs(abs(as.numeric(x)-(ploidy/2))-(ploidy/2))), collapse = ""), ploidy = x$ploidy)
+  type.names <- names(table(type))
+  mrk.dist <- as.numeric(freq)
+  names(mrk.dist) <- apply(d.temp, 1 , paste, collapse = "-")
   w <- c("#FFFFFF", "#F0F0F0", "#D9D9D9", "#BDBDBD", "#969696",
          "#737373", "#525252", "#252525", "#000000")
-  pal<-colorRampPalette(w)(length(type.names))
+  pal <- colorRampPalette(w)(length(type.names))
   oldpar <- par(mar = c(5,4,1,2))
   on.exit(par(oldpar))
   layout(matrix(c(1,1,1,2,3,3,6,4,5), 3, 3), widths = c(1.2,3,.5), heights = c(1.5,2,3))
@@ -338,32 +338,32 @@ plot.mappoly.data <- function(x, thresh.line=10e-6, ...)
           ylab = "Dosage combination", horiz = TRUE)
   if(is.null(x$chisq.pval))
   {
-    plot(0, 0, axes = FALSE, xlab = "", ylab="", type = "n")
-    text(x=0, y=0, labels = "No segregation test", cex = 2)
+    plot(0, 0, axes = FALSE, xlab = "", ylab = "", type = "n")
+    text(x = 0, y = 0, labels = "No segregation test", cex = 2)
   } else{
-    par(mar=c(1,1,1,2))
-    par(xaxs="i")
-    plot(log10(x$chisq.pval), axes = FALSE, xlab = "", ylab="", pch = 16, 
-         col = rgb(red=0.2, green=0.2, blue=1.0, alpha=0.2))
+    par(mar = c(1,1,1,2))
+    par(xaxs = "i")
+    plot(log10(x$chisq.pval), axes = FALSE, xlab = "", ylab = "", pch = 16, 
+         col = rgb(red = 0.2, green = 0.2, blue = 1.0, alpha = 0.2))
     axis(4, line = 1)
     mtext(text = bquote(log[10](P)), side = 4, line = 4, cex = .7)
-    lines(x=c(0, x$n.mrk), y = rep(log10(thresh.line),2), col = 2, lty = 2)
+    lines(x = c(0, x$n.mrk), y = rep(log10(thresh.line),2), col = 2, lty = 2)
   }
-  par(mar=c(5,1,0,2))
+  par(mar = c(5,1,0,2))
   
-  if(x$m == 2) {
+  if(x$ploidy  ==  2) {
     pal <- c("black", "#FC8D59", "#FFFFBF", "#91CF60")
-  }else if(x$m == 4){
+  }else if(x$ploidy  ==  4){
     pal <- c("black", "#D7191C", "#FDAE61", "#FFFFBF", "#A6D96A", "#1A9641")
-  }else if(x$m == 6){
+  }else if(x$ploidy  ==  6){
     pal <- c("black", "#D73027", "#FC8D59", "#FEE08B", "#FFFFBF", "#D9EF8B", "#91CF60", "#1A9850")
-  }else if(x$m == 8){
+  }else if(x$ploidy  ==  8){
     pal <- c("black", "#D73027", "#F46D43", "#FDAE61", "#FEE08B", "#FFFFBF", "#D9EF8B", "#A6D96A", "#66BD63", "#1A9850") 
-  } else pal <- c("black", gg_color_hue(x$m))
+  } else pal <- c("black", gg_color_hue(x$ploidy))
   
-  names(pal)<-c(-1:x$m)
+  names(pal) <- c(-1:x$ploidy)
   M <- as.matrix(x$geno.dose)
-  M[M==x$m+1]<--1
+  M[M == x$ploidy+1] <- -1
   image(x = 1:nrow(M), z = M, axes = FALSE, xlab = "",
         col = pal[as.character(sort(unique(as.vector(M))))], useRaster = TRUE)
   mtext(text = "Markers", side = 1, line = .4)
@@ -371,24 +371,24 @@ plot.mappoly.data <- function(x, thresh.line=10e-6, ...)
   par(mar = c(0,0,0,0))
   plot(0:10,0:10, type = "n", axes = FALSE, xlab = "", ylab = "")
   legend(0,10, 
-         horiz=FALSE, 
-         legend=c("missing", 0:x$m),
-         pch=22,
+         horiz = FALSE, 
+         legend = c("missing", 0:x$ploidy),
+         pch = 22,
          pt.cex = 3,
-         pt.bg=pal, pt.lwd = 0,
-         bty = "n", xpd=TRUE)
+         pt.bg = pal, pt.lwd = 0,
+         bty = "n", xpd = TRUE)
   if(!is.null(x$elim.correspondence)){
     par(mar = c(5,0,2,2))
     red = round(100*nrow(x$elim.correspondence)/(length(x$kept)+nrow(x$elim.correspondence)),1)
     mat = matrix(c(100-red, red), ncol = 1)
-    w = barplot(mat, main="",
-                xlab="", col=c(blues9[3],blues9[6]),
+    w = barplot(mat, main = "",
+                xlab = "", col = c(blues9[3],blues9[6]),
                 axes = F, width = .5, border = NA, xlim = c(0,1)) 
     
     text(w, c((100-red)/2,   100 - red/2),  c(paste0(100 - red, " %"), paste0(red, " %")))
     mtext(text = "Unique vs. Redundant", line = -1, side = 4, cex = .8)
   }
-  par(mfrow=c(1,1))
+  par(mfrow = c(1,1))
 }
 
 
