@@ -1,6 +1,6 @@
-#' Re-estimate genetic map using dosage prior probability distribution
+#' Re-estimate genetic map using dosage.priorprobability distribution
 #'
-#' This function considers dosage prior distribution when re-estimating
+#' This function considers dosage.priordistribution when re-estimating
 #' a genetic map using Hidden Markov models
 #'
 #' @param input.map an object of class \code{mappoly.map}
@@ -19,17 +19,17 @@
 #' @return A list of class \code{mappoly.map} with two elements: 
 #' 
 #' i) info:  a list containing information about the map, regardless of the linkage phase configuration:
-#' \item{m}{the ploidy level}
+#' \item{ploidy}{the ploidy level}
 #' \item{n.mrk}{number of markers}
 #' \item{seq.num}{a vector containing the (ordered) indices of markers in the map, 
 #'                according to the input file}
 #' \item{mrk.names}{the names of markers in the map}
-#' \item{seq.dose.p}{a vector containing the dosage in parent 1 for all markers in the map}
-#' \item{seq.dose.q}{a vector containing the dosage in parent 2 for all markers in the map}
-#' \item{sequence}{a vector indicating the sequence (usually chromosome) each marker belongs 
+#' \item{seq.dose.p1}{a vector containing the dosage in parent 1 for all markers in the map}
+#' \item{seq.dose.p2}{a vector containing the dosage in parent 2 for all markers in the map}
+#' \item{chrom}{a vector indicating the sequence (usually chromosome) each marker belongs 
 #'                 as informed in the input file. If not available, 
-#'                 \code{sequence = NULL}}
-#' \item{sequence.pos}{physical position (usually in megabase) of the markers into the sequence}
+#'                 \code{chrom = NULL}}
+#' \item{genome.pos}{physical position (usually in megabase) of the markers into the sequence}
 #' \item{seq.ref}{reference base used for each marker (i.e. A, T, C, G). If not available, 
 #'                 \code{seq.ref = NULL}}                 
 #' \item{seq.alt}{alternative base used for each marker (i.e. A, T, C, G). If not available, 
@@ -52,7 +52,7 @@
 #'     submap <- get_submap(solcap.dose.map[[1]], mrk.pos = 1:20, verbose = FALSE)
 #'     prob.submap <- est_full_hmm_with_prior_prob(submap,
 #'                                                 dat.prob = tetra.solcap.geno.dist,
-#'                                                 tol=10e-4, 
+#'                                                 tol = 10e-4, 
 #'                                                 verbose = TRUE)
 #'     prob.submap
 #'     plot_map_list(list(dose = submap, prob = prob.submap), 
@@ -69,7 +69,7 @@
 #'
 #' @export est_full_hmm_with_prior_prob
 #'
-est_full_hmm_with_prior_prob<-function(input.map, dat.prob = NULL, phase.config = "best", 
+est_full_hmm_with_prior_prob <- function(input.map, dat.prob = NULL, phase.config = "best", 
                                        tol = 10e-4, verbose = FALSE)
 {
   if (!inherits(input.map, "mappoly.map")) {
@@ -77,13 +77,13 @@ est_full_hmm_with_prior_prob<-function(input.map, dat.prob = NULL, phase.config
   }
   ## choosing the linkage phase configuration
   LOD.conf <- get_LOD(input.map, sorted = FALSE)
-  if(phase.config == "best") {
+  if(phase.config  ==  "best") {
     i.lpc <- which.min(LOD.conf)
   } else if (phase.config > length(LOD.conf)) {
     stop("invalid linkage phase configuration")
   } else i.lpc <- phase.config
   if(is.null(dat.prob)){
-    if(nrow(get(input.map$info$data.name, pos=1)$geno)==get(input.map$info$data.name, pos=1)$n.mrk){
+    if(nrow(get(input.map$info$data.name, pos = 1)$geno) == get(input.map$info$data.name, pos = 1)$n.mrk){
       stop("
             The dataset associated to 'input.map'
             contains no genotypic probability distribution.
@@ -91,33 +91,33 @@ est_full_hmm_with_prior_prob<-function(input.map, dat.prob = NULL, phase.config
            'dat.prob'.
            ")
     } else {
-      dat.prob <- get(input.map$info$data.name, pos=1)
+      dat.prob <- get(input.map$info$data.name, pos = 1)
       }
   }
-  mrk<-NULL
+  mrk <- NULL
   original.map.mrk <- input.map$info$mrk.names
   dat.prob.pos <- match(original.map.mrk, dat.prob$mrk.names)
-  which.is.na<-which(is.na(dat.prob.pos))
+  which.is.na <- which(is.na(dat.prob.pos))
   if(length(which.is.na) > 0)
     stop("Markers", original.map.mrk[which.is.na], "are not present in the 'dat.prob' object")
-  temp.map<-input.map
-  temp.map$info$seq.num <- temp.map$maps[[i.lpc]]$seq.num<-dat.prob.pos
-  names(temp.map$maps[[i.lpc]]$seq.ph$P)<-names(temp.map$maps[[i.lpc]]$seq.ph$Q)<-dat.prob.pos
+  temp.map <- input.map
+  temp.map$info$seq.num <- temp.map$maps[[i.lpc]]$seq.num <- dat.prob.pos
+  names(temp.map$maps[[i.lpc]]$seq.ph$P) <- names(temp.map$maps[[i.lpc]]$seq.ph$Q) <- dat.prob.pos
   if(!all(sort(get(temp.map$info$data.name, pos = 1)$ind.names) %in% sort(get(input.map$info$data.name, pos = 1)$ind.names)))
     stop("The individuals are different in the new and original datasets")
-  geno<-subset(dat.prob$geno, mrk%in%original.map.mrk)
-  geno.new<-NULL
+  geno <- subset(dat.prob$geno, mrk%in%original.map.mrk)
+  geno.new <- NULL
   for(i in unique(geno$ind))
-    geno.new<-rbind(geno.new, geno[geno[,"ind"] == i, ][match(original.map.mrk, geno[,"mrk"]),])
+    geno.new <- rbind(geno.new, geno[geno[,"ind"]  ==  i, ][match(original.map.mrk, geno[,"mrk"]),])
   g <- as.double(t(geno.new[, -c(1:2)]))
   if (verbose) cat("
  ----------------------------------------------
  INFO: running HMM using full transition space:
        this operation may take a while.
 -----------------------------------------------\n")
-  map.res<-poly_hmm_est(m = as.numeric(temp.map$info$m),
+  map.res <- poly_hmm_est(ploidy = as.numeric(temp.map$info$ploidy),
                         n.mrk = as.numeric(temp.map$info$n.mrk),
-                        n.ind = get(input.map$info$data.name, pos=1)$n.ind,
+                        n.ind = get(input.map$info$data.name, pos = 1)$n.ind,
                         p = as.numeric(unlist(temp.map$maps[[i.lpc]]$seq.ph$P)),
                         dp = as.numeric(cumsum(c(0, sapply(temp.map$maps[[i.lpc]]$seq.ph$P, function(x) sum(length(x)))))),
                         q = as.numeric(unlist(temp.map$maps[[i.lpc]]$seq.ph$Q)),
@@ -128,7 +128,7 @@ est_full_hmm_with_prior_prob<-function(input.map, dat.prob = NULL, phase.config
                         tol = tol)
   if(verbose)
     cat("\n")
-  temp.map$maps[[i.lpc]]$seq.rf<-map.res$rf
-  temp.map$maps[[i.lpc]]$loglike<-map.res$loglike
+  temp.map$maps[[i.lpc]]$seq.rf <- map.res$rf
+  temp.map$maps[[i.lpc]]$loglike <- map.res$loglike
   return(temp.map)
 }
